Module context_budget
synaptic_
core
0.3.0
Module context_
budget
Module Items
Structs
In crate synaptic_
core
synaptic_core
Module
context_
budget
Structs

Context
Budget
Assembles messages from multiple context slots within a token budget.
Context
Slot
A slot of context to include in the budget.
Priority
Priority level for context slots. Lower values = higher priority.